@@ -5,12 +5,12 @@ use strict;
 use Carp;
 use Class::Load;
 
-our $VERSION = '0.399_03';
+our $VERSION = '0.399_04';
 
 sub engine {
     my $class = shift;
     my %args  = @_;
-    my $type  = delete $args{type} or croak "type required";
+    my $type  = delete $args{type} or confess "type required";
     my $engine_class
         = $type =~ s/^\+//
         ? $type
